@@ -5,6 +5,8 @@ import os
 from .fetch_handler import FetchHandler
 from .build_handler import BuildHandler
 from forest.common.eval_handler import EvalHandler
+from forest.common.recipe import Cookbook
+
 
 class BasicPackage:
 
@@ -18,7 +20,6 @@ class BasicPackage:
         self.depends = depends if depends is not None else list()
         
 
-
 class Package(BasicPackage):
 
     """
@@ -29,44 +30,10 @@ class Package(BasicPackage):
     # the path to the recipe directory
     _path = None
 
-    
     def __init__(self, name, depends: List[str]) -> None:
         super().__init__(name, depends=depends)
         self.fetcher = FetchHandler(name)
         self.builder = BuildHandler(name)
-    
-    @classmethod
-    def set_recipe_path(cls, path):
-        cls._path = path
-
-    
-    @classmethod
-    def get_recipe_path(cls):
-        """
-        Returns the default (and for now only) directory with recipes inside.
-        This path is relative to this file's directory.
-        """
-
-        if cls._path is None:
-            raise ValueError("Recipes' folder path missing")
-
-        return cls._path
-    
-
-    @staticmethod
-    def get_available_recipes() -> List[str]:
-        """
-        Returns a list of available recipe names
-        """
-        path = Package.get_recipe_path()
-        if not os.path.isdir(path):
-            return []
-
-        files = [f for f in os.listdir(path) if os.path.isfile(os.path.join(path, f))]
-        files = [os.path.splitext(f)[0] for f in files]
-        files.sort()
-        return files
-
 
     @staticmethod
     def from_yaml(name, recipe) -> 'Package':
@@ -86,6 +53,9 @@ class Package(BasicPackage):
 
         # dependency list if any
         depends = recipe.get('depends', list())
+        if depends is None:
+            # empty entry "depends:" in yaml is parsed as None
+            depends = list()
         depends_if = recipe.get('depends_if', dict())
         depends.extend(eh.parse_conditional_dict(depends_if))
 
@@ -100,7 +70,6 @@ class Package(BasicPackage):
             pkg.builder = BuildHandler.from_yaml(pkgname=name, data=recipe['build'], recipe=recipe)
 
         return pkg
-        
 
     @staticmethod
     def from_file(file) -> 'Package':
@@ -111,6 +80,8 @@ class Package(BasicPackage):
         name = os.path.splitext(os.path.basename(file))[0]
         with open(file, 'r') as f:
             yaml_dict = yaml.safe_load(f.read())
+            if yaml_dict is None:
+                yaml_dict = dict()
             return Package.from_yaml(name=name, recipe=yaml_dict)
 
     @staticmethod
@@ -124,7 +95,7 @@ class Package(BasicPackage):
             RuntimeError: recipe file does not exist
         """
 
-        filename = os.path.join(Package.get_recipe_path(), name + '.yaml')
+        filename = os.path.join(Cookbook.get_recipe_path(), name + '.yaml')
         if not os.path.exists(filename):
             # TODO more specific exception
             raise FileNotFoundError(f'{filename} does not exist')
