@@ -1,6 +1,9 @@
+import typing
+
 from forest.common import proc_utils
 import shutil
 
+
 class GitTools:
 
     def __init__(self, srcdir) -> None:
@@ -12,7 +15,8 @@ class GitTools:
             tag: str,
             proto='ssh', 
             recursive=False,
-            depth=None):
+            depth=None,
+            single_branch=False):
 
         if proto == 'ssh':
             addr = f'git@{server}:{repository}'
@@ -25,6 +29,9 @@ class GitTools:
         # create command
         cmd = ['git', 'clone', '--branch', tag]
         
+        if single_branch:
+            cmd.append('--single-branch')
+
         if recursive:
             cmd.append('--recursive')
 
@@ -36,9 +43,9 @@ class GitTools:
         # clone, and delete the source folder on failure
         # (either exception or git returns != 0) 
         try:
-             clone_ok = proc_utils.call_process(args=cmd)
-             if not clone_ok:
-                 self.rm()
+            clone_ok = proc_utils.call_process(args=cmd)
+            if not clone_ok:
+                self.rm()
         except BaseException as e:
             # remove src and re-raise exception
             self.rm()
@@ -51,4 +58,3 @@ class GitTools:
 
     def rm(self):
         shutil.rmtree(self.srcdir,  ignore_errors=True)
-
